@@ -20,17 +20,17 @@ arma_inline
 const Op<T1, op_median>
 median
   (
-  const Base<typename T1::elem_type,T1>& X,
+  const T1& X,
   const uword dim = 0,
-  const typename enable_if<resolves_to_vector<T1>::value == false>::result* junk1 = 0,
-  const typename enable_if<is_basevec<T1>::value == false>::result* junk2 = 0
+  const typename enable_if< is_arma_type<T1>::value       == true  >::result* junk1 = 0,
+  const typename enable_if< resolves_to_vector<T1>::value == false >::result* junk2 = 0
   )
   {
   arma_extra_debug_sigprint();
   arma_ignore(junk1);
   arma_ignore(junk2);
   
-  return Op<T1, op_median>(X.get_ref(), dim, 0);
+  return Op<T1, op_median>(X, dim, 0);
   }
 
 
@@ -40,7 +40,7 @@ arma_inline
 const Op<T1, op_median>
 median
   (
-  const Base<typename T1::elem_type,T1>& X,
+  const T1& X,
   const uword dim,
   const typename enable_if<resolves_to_vector<T1>::value == true>::result* junk = 0
   )
@@ -48,27 +48,7 @@ median
   arma_extra_debug_sigprint();
   arma_ignore(junk);
   
-  return Op<T1, op_median>(X.get_ref(), dim, 0);
-  }
-
-
-
-template<typename T1>
-inline
-arma_warn_unused
-typename T1::elem_type
-median
-  (
-  const Base<typename T1::elem_type,T1>& X,
-  const arma_empty_class junk1 = arma_empty_class(),
-  const typename enable_if<resolves_to_vector<T1>::value == true>::result* junk2 = 0
-  )
-  {
-  arma_extra_debug_sigprint();
-  arma_ignore(junk1);
-  arma_ignore(junk2);
-  
-  return op_median::median_vec(X.get_ref());
+  return Op<T1, op_median>(X, dim, 0);
   }
 
 
@@ -81,7 +61,7 @@ median
   (
   const T1& X,
   const arma_empty_class junk1 = arma_empty_class(),
-  const typename enable_if<is_basevec<T1>::value == true>::result* junk2 = 0
+  const typename enable_if<resolves_to_vector<T1>::value == true>::result* junk2 = 0
   )
   {
   arma_extra_debug_sigprint();
